Enum boing::image::IntoReprError
source · pub enum IntoReprError {
TooWide,
TooTall,
StrideTooWide,
}Variants
TooWide
The width of the given representation exceeds that allowed by libui-ng.
TooTall
The height of the given representation exceeds that allowed by libui-ng.
StrideTooWide
The row stride of the given representation exceeds that allowed by libui-ng.